stylist.issue — Stylist 0.3.dev1 documentation

# stylist.issue

Issues found in the source.

Classes

`Issue`(description[, line, filename]) | Holds details pertaining to an issue with the source.

class stylist.issue.Issue(description, line=None, filename=None)

  Bases: `object`

  Holds details pertaining to an issue with the source.

  Parameters

    - description (`str`) – Free-format string describing the issue.

    - line (`Optional`[`int`]) – Line number where issue found.

    - filename (`Optional`[`str`]) – File in which issue found.

  property description: str

    Description of this issue.

    Return type

      `str`

  property filename: Optional[str]

    Filename associated with this issue.

    Return type

      `Optional`[`str`]

  property line: Optional[int]

    Line number associated with this issue.

    Return type

      `Optional`[`int`]

  set_filename(filename)

    Associates a filename with this issue.

    Return type

      `None`